@@ -103,8 +103,8 @@ typedef unsigned long uint32;
 #endif
 */
 
-#define CONFIG_PATH     "/tmp/genek"
-#define DATABASE_PATH   "/tmp/genek"
+#define CONFIG_PATH     "/usr/local/bin/tw"
+#define DATABASE_PATH   "/var/tripwire"
 
 /******* name of Tripwire files **************************************
  *
@@ -147,7 +147,7 @@ typedef unsigned long uint32;
  *
  *********************************************************************/
 
-#define DEFAULTIGNORE	"R-3456789"
+#define DEFAULTIGNORE	"R-23456789"
 
 /******* Temporary file template ************************************
  *
