@@ -1,10 +1,6 @@
-#ifndef lint
-static char rcsid[] = "$Id: main.c,v 1.31 1994/08/26 08:23:03 gkim Exp $";
-#endif
-
 /************************************************************************
  *
- *   All files in the distribution of Tripwire are Copyright 1992, 1993 by 
+ *   All files in the distribution of Tripwire are Copyright 1992-1998 by 
  *   the Purdue Research Foundation of Purdue University.  All rights
  *   reserved.  Some individual files in this distribution may be covered
  *   by other copyrights, as noted in their embedded comments.
@@ -120,7 +116,7 @@ struct list *olddbase_list = (struct list *) NULL;
 
 int debuglevel = 1;
 int verbosity = 0;
-int loosedir = 0;
+int loosedir = 1;			/* now defaults to true.  ghk VCC 7/1/98 */
 static int dbaseinit = 0;
 int printhex = 0;
 static char **pp_updateentries = NULL;
@@ -178,6 +174,22 @@ usage()
     exit(1);
 }
 
+
+static void banner()
+{
+	fprintf(stderr, "\nTripwire(tm) Intrusion Detection Software v%s\n\n",
+					VERSION_NUM);
+
+	fprintf(stderr, "This release is for single CPU, single-site, end-use purposes.  For commercial\n");
+	fprintf(stderr, "applications or product information, please visit the Visual Computing\n");
+	fprintf(stderr, "Corporation web site at http://www.visualcomputing.com/tripwire, or call us\n");
+	fprintf(stderr, "at (503) 223-0280.\n\n");
+
+	fprintf(stderr, "Tripwire(tm) Copyright 1992-98 by the Purdue Research Foundation of Purdue\n");
+	fprintf(stderr, "University, and distributed by Visual Computing Corporation under exclusive\n");
+	fprintf(stderr, "license arrangements.\n\n");
+}
+
 /*
  * void
  * version()
@@ -189,13 +201,13 @@ usage()
 static void
 version()
 {
-    fprintf(stderr, "\nTripwire version %s (patchlevel %d)\n\n", version_num,
-			    PATCHLEVEL);
-    fprintf(stderr, "Copyright (c) 1992, 1993, 1994 Purdue Research Foundation\n");
-    fprintf(stderr, "\tBy Gene Kim, Eugene Spafford\n\n");
+	/* We already printed out the banner, so skip it. */
+	/* banner(); */
     exit(0);
 }
 
+
+
 int
 main(argc, argv)
     int argc;
@@ -405,6 +417,11 @@ main(argc, argv)
 
     /* argument sanity checking */
 
+    /* Display Visual Computing Corporation information */
+    if (!quietmode) {
+	    banner();
+    }
+
     /* eliminate aliases of stdin 
      * 	(our canonical form is using fd 0)
      */
@@ -615,12 +632,6 @@ printf("Updating entry: %s\n", filename_escape(pc));
 	}
 	update_mark(pp_updateentries, numupdateentries);
 	cleanup();
-	if (!quietmode) {
-	    fprintf(stderr, "###\n");
-	    fprintf(stderr, "### If you changed the tw.config file, remember to run `twdb_check.pl' to\n");
-	    fprintf(stderr, "### ensure database consistency.\n");
-	    fprintf(stderr, "### See the README file for details.\n");
-	}
 	exit(0);
     }
 
