@@ -1,14 +1,9 @@
-#ifndef lint
-static char rcsid[] = "$Id: preen.report.c,v 1.20 1994/08/04 03:44:34 gkim Exp $";
-#endif
-
 /*
  * preen.report.c
  *
  *	report generation given the data from preening
  *
  * Gene Kim
- * Purdue University
  */
 
 #include "../include/config.h"
@@ -69,6 +64,8 @@ preen_report(interactive, ppp_updateentries)
     char *s;
     int unignored;
     FILE *fttyin = NULL, *fttyout = NULL;
+    int ch_ignored, ch_reported;
+    int nfile_violations;
 
     /* we'll use a local variable for this */
     /*
@@ -93,20 +90,28 @@ preen_report(interactive, ppp_updateentries)
 
     unignored = preen_change_count();
 
+    /* calculate some statistics here */
+    ch_ignored = diff_added_num + diff_deleted_num + diff_changed_num -
+	      		unignored;
+    ch_reported = unignored;
+    nfile_violations = diff_added_num + diff_deleted_num + ch_reported;
+
     if (!quietmode) {
-    fprintf(stderr, "###\n");
-    fprintf(stderr, "###\t\t\tTotal files scanned:\t\t%d\n", files_scanned_num);
-    fprintf(stderr, "###\t\t\t      Files added:\t\t%d\n", diff_added_num);
-    fprintf(stderr, "###\t\t\t      Files deleted:\t\t%d\n", diff_deleted_num);
-    fprintf(stderr, "###\t\t\t      Files changed:\t\t%d\n", diff_changed_num);
-    fprintf(stderr, "###\n");
-    fprintf(stderr, "###\t\t\tAfter applying rules:\n");
-    fprintf(stderr, "###\t\t\t      Changes discarded:\t%d\n",
-			diff_added_num + diff_deleted_num + diff_changed_num -
-	      		(unignored) );
-    fprintf(stderr, "###\t\t\t      Changes remaining:\t%d\n",
-		        unignored + diff_added_num + diff_deleted_num);
-    fprintf(stderr, "###\n");
+	if (nfile_violations == 0) {
+	    fprintf(stderr, "###\n");
+	    fprintf(stderr, "###\t\t\tAll files match Tripwire database.  Looks okay!\n");
+	    fprintf(stderr, "###\n");
+	}
+	else {
+	    fprintf(stderr, "###\n");
+	    fprintf(stderr, "###\t\t\tTotal files scanned:\t\t%d\n", files_scanned_num);
+	    fprintf(stderr, "###\t\t\t      Files added:\t\t%d\n", diff_added_num);
+	    fprintf(stderr, "###\t\t\t      Files deleted:\t\t%d\n", diff_deleted_num);
+	    fprintf(stderr, "###\t\t\t      Files changed:\t\t%d\n", ch_reported);
+	    fprintf(stderr, "###\n");
+	    fprintf(stderr, "###\t\t\tTotal file violations:\t\t%d\n", nfile_violations);
+	    fprintf(stderr, "###\n");
+	}
     }
 
     /****** added ******/
