@@ -43,7 +43,7 @@ echo "=== $ME: Setting up auxiliary scripts ==="
 
 # build run()
 cat << 'EOF' > $MYRUN
-    #sleep 1		# agh!  Bug in SunOS tmpfs!!!
+    sleep 2		# agh!  Fast tmpfs!!!
     echo running Tripwire
     echo $*
     $*
