@@ -4,14 +4,13 @@
 
 HOSTNAME=hostname
 # check to see if we ran from top-level makefile!
-if [ $# -ne 2 ]
+if [ $# -ne 1 ]
 then 
    echo "Sorry!  You must run this test from the top-level Makefile!"
    exit 1
 fi
 
 HOSTNAME=$1
-DIST=$2
 ME=$0
 
 cat << GHK
@@ -19,12 +18,8 @@ cat << GHK
 
     This shell script tests all the Tripwire signature routines.
 Consequently, this test may take awhile to complete, because even the
-slowest signature routines are exercised.  On a Sequent Symmetry
-running 16 Mhz Intel 80386s, this test takes over five minutes to
-complete.
-
-    This same test using only the MD5 routines completes in less
-than 30 seconds.
+slowest signature routines are exercised.  On a 200 MHz Intel Pentium 
+machine, this test takes 15 seconds to complete. 
 
     This test suite will ascertain whether the byte-ordering and 
 machine-dependent routines are working correctly.
@@ -41,8 +36,8 @@ HOST=`$HOSTNAME`
 CURRPATH=`pwd`
 CURRPATH=`echo $CURRPATH | sed s,/tests$,,`
 
-sed s,/tmp/genek/$DIST,$CURRPATH, < ./tw.db_TEST > ./tw.db_TEST.@; 
-sed s,/tmp/genek/$DIST,$CURRPATH, < ./tw.conf.test > ./@tw.config; 
+sed s,/build,$CURRPATH, < ./tw.db_TEST > ./tw.db_TEST.@; 
+sed s,/build,$CURRPATH, < ./tw.conf.test > ./@tw.config; 
 
 ../src/tripwire -loosedir -c ./@tw.config -d ./tw.db_TEST.@; 
 
